@@ -31,7 +31,13 @@ def main():
     print(result)
     print(f"Target schema has less {len(result)} (table_name,column_name) than source schema")
     result = result.to_html()
-    f = open("/src/schema_compare/report.html","r")
+
+    import os
+    absolute_path = os.path.dirname(__file__)
+    relative_path = "report.html"
+    full_path = os.path.join(absolute_path, relative_path)
+
+    f = open(full_path,"r")
 
     content = f.read()
 
